pandas\.io\.formats\.style\.Styler\.set\_table\_attributes
==========================================================

.. currentmodule:: pandas.io.formats.style

.. automethod:: Styler.set_table_attributes